Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1533)

Unified Diff: content/shell/test_runner/web_test_delegate.h

Issue 2970183002: color: Use ColorSpace for plumbing (Closed)
Patch Set: Add missed places Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/shell/test_runner/test_runner_for_specific_view.cc ('k') | content/test/layouttest_support.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/shell/test_runner/web_test_delegate.h
diff --git a/content/shell/test_runner/web_test_delegate.h b/content/shell/test_runner/web_test_delegate.h
index 1bd00de7c4d0ae15171e485afdbc0d9fc6cb7027..58f0fb0e7bc2fc54e0be3f1de06caf0fd657cccf 100644
--- a/content/shell/test_runner/web_test_delegate.h
+++ b/content/shell/test_runner/web_test_delegate.h
@@ -181,8 +181,8 @@ class WebTestDelegate {
// Returns whether or not the use-zoom-for-dsf flag is enabled.
virtual bool IsUseZoomForDSFEnabled() = 0;
- // Change the device color profile while running a layout test.
- virtual void SetDeviceColorProfile(const std::string& name) = 0;
+ // Change the device color space while running a layout test.
+ virtual void SetDeviceColorSpace(const std::string& name) = 0;
// Set the bluetooth adapter while running a layout test, uses Mojo to
// communicate with the browser.
« no previous file with comments | « content/shell/test_runner/test_runner_for_specific_view.cc ('k') | content/test/layouttest_support.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698